<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\Coupons;
use Illuminate\Http\Request;

class CouponsController extends Controller
{
    public function __construct()
    {
        $this->middleware(['permission:coupons']);

    }
    public function index()
    {
        $rows = Coupons::orderByDesc('id')->get();
        return view('admin.coupons.index', compact('rows'));
    }

    public function create()
    {
        return view('admin.coupons.create');
    }

    public function store(Request $request)
    {
        $this->validate($request, [
            'code' => 'required',
            'discount_amount' => 'required',
            'discount_type' => 'required|in:discount,amount',
            'use_count' => 'required',
            'max_discount' => 'required',
            'start_date'=>'required',
            'end_date'=>'required|after:start_date'
        ]);

        Coupons::create($request->all());
        toast('تمت العملية بنجاح', 'success');
        return redirect()->route('coupons.index');
    }

    public function edit($id)
    {
        $row = Coupons::findOrFail($id);
        return view('admin.coupons.edit', compact('row'));
    }

    public function update($id, Request $request)
    {
        $this->validate($request, [
            'code' => 'required',
            'discount_amount' => 'required',
            'use_count' => 'required',
            'max_discount' => 'required',
            'discount_type' => 'required|in:discount,amount',

            'start_date'=>'required',
            'end_date'=>'required|after:start_date'
        ]);

        Coupons::whereId($id)->update($request->except('_token', '_method'));
        toast('تمت العملية بنجاح', 'success');
        return redirect()->route('coupons.index');
    }

    public function destroy($id)
    {
        Coupons::destroy($id);
        toast('تمت العملية بنجاح', 'success');
        return redirect()->route('coupons.index');
    }
}
