<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\Notification;
use App\Models\Offer;
use App\Models\Order;
use App\Models\Setting;
use App\Models\UserToken;
use App\User;
use Carbon\Carbon;
use Edujugon\PushNotification\PushNotification;
use Illuminate\Http\Request;

class NewOrdersController extends Controller
{
    public function index()
    {
        $rows = Order::whereStatus('admin_wait')->orderByDesc('id')->get();
        return view('admin.new_orders.index', compact('rows'));
    }

    public function edit($id)
    {
        $row = Order::find($id);
        return view('admin.new_orders.edit', compact('row'));
    }

    public function update($id, Request $request)
    {
        $request->validate([
            'title' => 'required|max:191',
            'description' => 'required',
            'address_id' => 'required',
            'date' => 'required|max:191',
            'days_count' => 'required|max:191'

        ]);


        $order = Order::findOrFail($id);

        $offer = Offer::find($order->offer_id);


        // لو موافق

        if ($request['status'] == 'in_progress') {


            $setting = Setting::first();
            $offerAndDeliverPrice = (integer)$offer->price + (integer)$offer->deliver_price;
            $allPriceAndFee = $offerAndDeliverPrice + ($offerAndDeliverPrice * $setting->fee / 100);

            $firstPay = $allPriceAndFee * 15 / 100; // Client with additional fee
            $firstPayWorker = $offerAndDeliverPrice * 15 / 100; // To Worker wallet without additional fee
            $secondPay = $allPriceAndFee - $firstPay;


            Order::where('id', $id)->update([


                'status' => 'in_progress',
                'payment_type' => 'bank',
                'firstPayCheck' => 'true',

            ]);


            $order_offer_price = $order->price_offer;
            $order_deliver_price = $order->deliver_price;

            $order_all_price = $order->total_price;


            $worker = User::find($order->worker_id);
            $commission = 0;
            $setting = Setting::first();
            if ($worker->special_commission) {
                $commission = $worker->special_commission;
            } else {
                $commission = $setting->single_commission;

            }


            $add_commission = $firstPayWorker - ($firstPayWorker * $commission / 100);

            $worker->wallet += $add_commission;


            $additional_fee = $order_all_price - ($order_offer_price + $order_deliver_price); // additional fee

            $order['system_money'] = $additional_fee + ($firstPayWorker * $commission / 100);


            // send notification to worker
            $notification = new Notification();
            $notification['user_id'] = $offer->worker_id;
            $notification['order_id'] = $offer->order_id;
            $notification['body->ar'] = " تمت الموافقة علي عرضكم علي طلب رقم  $order->code";
            $notification['body->en'] = " Your offer for order no. $order->code is approved ";
            $notification['type'] = 'client_accept';
            $notification->save();
            $tokens = UserToken::where('user_id', $offer->worker_id)->get();
            $push = new PushNotification('fcm');
            foreach ($tokens as $token) {


                $title = $notification->body['ar'];
                $body = $notification->body['ar'];

                if ($token->device_type == 'ios') {
                    $msg = [
                        'data' => [
                            'title_ar' => $notification['body->ar'],
                            'title_en' => $notification['body->en'],
                            'body_ar' => $notification['body->ar'],
                            'body_en' => $notification['body->en'],
                            'type' => 'client_accept',
                            'sound' => 'default',
                            'title' => $title,
                            'body' => $body,
                            'order_id' => $order->id,
                            'click_action' => 'FCM_PLUGIN_ACTIVITY',
                        ],
                        'notification' => [
                            'title_ar' => $notification['body->ar'],
                            'title_en' => $notification['body->en'],
                            'body_ar' => $notification['body->ar'],
                            'body_en' => $notification['body->en'],
                            'type' => 'client_accept',
                            'sound' => 'default',
                            'title' => $title,
                            'body' => $body,
                            'order_id' => $order->id,
                            'click_action' => 'FCM_PLUGIN_ACTIVITY',
                        ],
                        'priority' => 'high',
                    ];
                    $push->setMessage($msg)
                        ->setDevicesToken($token->token)
                        ->send();

                } else {
                    $msg = [
                        'data' => [
                            'title_ar' => $notification['body->ar'],
                            'title_en' => $notification['body->en'],
                            'body_ar' => $notification['body->ar'],
                            'body_en' => $notification['body->en'],
                            'type' => 'client_accept',
                            'sound' => 'default',
                            'title' => $title,
                            'body' => $body,
                            'order_id' => $order->id,
                            'click_action' => 'FCM_PLUGIN_ACTIVITY',
                        ],
                        'priority' => 'high',
                    ];
                    $push->setMessage($msg)
                        ->setDevicesToken($token->token)
                        ->send();

                }

            }


            $order = Order::findOrFail($id);
            if ($request['system_money'] == 'true') $order->system_money = 0;
            $order->title = $request['title'];
            $order->description = $request['description'];
            $order->status = $request['status'];
            $order->date = Carbon::parse($request->date);
            $order->address_id = $request['address_id'];
            $order->days_count = $request['days_count'];
            if ($request['status'] == 'paid') $order->secondPayCheck = 'true';

            $order->update();


            // Notification to client
            $notification = new Notification();
            $notification['user_id'] = $order->user_id;
            $notification['order_id'] = $order->id;
            $notification['body->ar'] = " تمت الموافقة علي   طلب رقم  $order->code";
            $notification['body->en'] = " Your Order  no. $order->code is approved ";
            $notification['type'] = 'admin_accept_order';
            $notification->save();
            $tokens = UserToken::where('user_id', $order->user_id)->get();
            $push = new PushNotification('fcm');
            foreach ($tokens as $token) {


                $title = $notification->body['ar'];
                $body = $notification->body['ar'];

                if ($token->device_type == 'ios') {
                    $msg = [
                        'data' => [
                            'title_ar' => $notification['body->ar'],
                            'title_en' => $notification['body->en'],
                            'body_ar' => $notification['body->ar'],
                            'body_en' => $notification['body->en'],
                            'type' => 'admin_accept_order',
                            'sound' => 'default',
                            'title' => $title,
                            'body' => $body,
                            'order_id' => $order->id,
                            'click_action' => 'FCM_PLUGIN_ACTIVITY',
                        ],
                        'notification' => [
                            'title_ar' => $notification['body->ar'],
                            'title_en' => $notification['body->en'],
                            'body_ar' => $notification['body->ar'],
                            'body_en' => $notification['body->en'],
                            'type' => 'admin_accept_order',
                            'sound' => 'default',
                            'title' => $title,
                            'body' => $body,
                            'order_id' => $order->id,
                            'click_action' => 'FCM_PLUGIN_ACTIVITY',
                        ],
                        'priority' => 'high',
                    ];
                    $push->setMessage($msg)
                        ->setDevicesToken($token->token)
                        ->send();

                } else {
                    $msg = [
                        'data' => [
                            'title_ar' => $notification['body->ar'],
                            'title_en' => $notification['body->en'],
                            'body_ar' => $notification['body->ar'],
                            'body_en' => $notification['body->en'],
                            'type' => 'admin_accept_order',
                            'sound' => 'default',
                            'title' => $title,
                            'body' => $body,
                            'order_id' => $order->id,
                            'click_action' => 'FCM_PLUGIN_ACTIVITY',
                        ],
                        'priority' => 'high',
                    ];
                    $push->setMessage($msg)
                        ->setDevicesToken($token->token)
                        ->send();

                }

            }

        }


        toast('تم حفظ التغييرات بنجاح', 'success');
        return redirect()->route('orders.index');


    }

    public function new_order_filter(Request $request)
    {
        $rows = Order::whereWorkerId($request['worker_id'])->whereStatus('admin_wait')->get();
        if ($request['start'] && $request['end']) {

            if ($request['start'] == $request['end']) {
                $rows = $rows->whereDate('created_at', '>=', Carbon::parse($request['start'])->toDateString());

            } else {
                $rows = $rows->whereBetween('created_at', [Carbon::parse($request['start']), Carbon::parse($request['end'])]);

            }
        } elseif ($request['start'] && $request['end'] == null) {

            $rows = $rows->where('created_at', '>=', Carbon::parse($request['start']));
        } elseif ($request['end'] && $request['start'] == null) {
            $rows = $rows->where('created_at', '<=', Carbon::parse($request['end']));
        }

        return view('admin.orders.index', compact('rows'));

    }

    public function destroy($id)
    {
        Order::destroy($id);
        toast('تم الحذف بنجاح', 'success');
        return redirect()->back();
    }

    public function show($id)
    {
        $row = Order::find($id);
        $categories = $row->categories;
        return view('admin.new_orders.show', compact('row', 'categories'));
    }
}
