<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\CategoriesOffer;
use App\Models\Category;
use App\Models\OfferCategoriesPivot;
use Illuminate\Http\Request;

class OffersController extends Controller
{
    public function __construct()
    {
        $this->middleware(['permission:offers']);

    }
    public function index()
    {
        $rows = CategoriesOffer::orderByDesc('id')->get();
        return view('admin.offers.index', compact('rows'));
    }


    public function create()
    {
        $categories = Category::where('price', '!=', null)->get();
        return view('admin.offers.create', compact('categories'));
    }

    public function store(Request $request)
    {
        $this->validate($request, [
            'name_ar' => 'required',
            'name_en' => 'required',
            'description_ar' => 'required',
            'description_en' => 'required',
            'image' => 'required|image',
            'categories' => 'required'
        ], [
            'categories.required' => 'رجاء ادخال اقسام مسعره'

        ]);

        $offer = new CategoriesOffer();
        $offer['name->ar'] = $request['name_ar'];
        $offer['name->en'] = $request['name_en'];
        $offer['description->ar'] = $request['description_ar'];
        $offer['description->en'] = $request['description_en'];
        if ($request->hasFile('image')) $offer->setImageAttribute();
        $offer->save();
        foreach ($request['categories'] as $category) {

            OfferCategoriesPivot::create([
                'category_id' => $category,
                'offer_id' => $offer->id
            ]);
        }

        toast('تمت العمليه بنجاح', 'success');
        return redirect()->route('offers.index');
    }

    public function edit($id)
    {
        $categories = Category::where('price', '!=', null)->get();
        $row = CategoriesOffer::findOrFail($id);
        return view('admin.offers.edit', compact('categories', 'row'));
    }

    public function update($id, Request $request)
    {
        $this->validate($request, [
            'name_ar' => 'required',
            'name_en' => 'required',
            'description_ar' => 'required',
            'description_en' => 'required',
            'image' => 'nullable|image',
            'categories' => 'required'
        ], [
            'categories.required' => 'رجاء ادخال اقسام مسعره'
        ]);


        $offer = CategoriesOffer::findOrFail($id);
        $offer['name->ar'] = $request['name_ar'];
        $offer['name->en'] = $request['name_en'];
        $offer['description->ar'] = $request['description_ar'];
        $offer['description->en'] = $request['description_en'];
        if ($request->hasFile('image')) $offer->setImageAttribute();
        $offer->update();
        OfferCategoriesPivot::whereOfferId($offer->id)->delete();
        foreach ($request['categories'] as $category) {

            OfferCategoriesPivot::create([
                'category_id' => $category,
                'offer_id' => $offer->id
            ]);
        }

        toast('تمت العمليه بنجاح', 'success');
        return redirect()->route('offers.index');


    }

    public function destroy($id)
    {
        CategoriesOffer::destroy($id);

        toast('تمت العمليه بنجاح', 'success');
        return redirect()->route('offers.index');
    }
}
