<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\Package;
use Illuminate\Http\Request;

class PackagesController extends Controller
{
    public function index()
    {
        $rows = Package::latest()->get();
        return view('admin.packages.index', compact('rows'));
    }

    public function create()
    {
        return view('admin.packages.create');
    }

    public function store(Request $request)
    {
        $request->validate([
            'title_ar' => 'required',
            'title_en' => 'required',
            'description_ar' => 'required',
            'description_en' => 'required',
            'price' => 'required',
            'duration' => 'required',
            'single_price' => 'required',
            'image' => 'required|image'

        ]);
        $package = new Package();
        $package['title->ar'] = $request['title_ar'];
        $package['title->en'] = $request['title_en'];
        $package['description->ar'] = $request['description_ar'];
        $package['description->en'] = $request['description_en'];
        $package['price'] = $request['price'];
        $package['duration'] = $request['duration'];
        $package['single_price'] = $request['single_price'];
        $package->setImageAttribute();
        $package->save();
        toast('تمت العملية بنجاح', 'success');
        return redirect()->route('packages.index');
    }

    public function edit($id)
    {
        $row = Package::find($id);
        return view('admin.packages.edit', compact('row'));
    }

    public function update($id, Request $request)
    {
        $request->validate([
            'title_ar' => 'required',
            'title_en' => 'required',
            'description_ar' => 'required',
            'description_en' => 'required',
            'price' => 'required',
            'duration' => 'required',
            'single_price' => 'required',
            'image' => 'nullable|image'
        ]);
        $package = Package::find($id);
        $package['title->ar'] = $request['title_ar'];
        $package['title->en'] = $request['title_en'];
        $package['description->ar'] = $request['description_ar'];
        $package['description->en'] = $request['description_en'];
        $package['price'] = $request['price'];
        $package['duration'] = $request['duration'];
        $package['single_price'] = $request['single_price'];

        if ($request->hasFile('image')) {
            $package->setImageAttribute();
        }
        $package->update();
        toast('تمت العملية بنجاح', 'success');
        return redirect()->route('packages.index');

    }

    public function destroy($id)
    {
        Package::destroy($id);
        toast('تمت العملية بنجاح', 'success');
        return back();
    }
}
