<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\Category;
use App\Models\WorkerCategory;
use App\User;
use Illuminate\Http\Request;

class PaidCategoriesController extends Controller
{
    public function __construct()
    {
        $this->middleware(['permission:paidCategories']);

    }
    public function index()
    {
        $rows = Category::where('price', '!=', null)->orderByDesc('id')->get();
        return view('admin.paidCategories.index', compact('rows'));
    }

    public function create()
    {
        $workers = User::whereType('worker')->whereAdminApprove('true')->get();
        return view('admin.paidCategories.create', compact('workers'));
    }

    public function store(Request $request)
    {
        $this->validate($request, [
            'name_ar' => 'required',
            'name_en' => 'required',
            'image' => 'required|image',
            'price' => 'required|max:191',
            'workers' => 'required'
        ], [
            'workers.required' => 'رجاء اختيار مقدميين خدمات'
        ]);

        $paidCategory = new Category();
        $paidCategory['name->ar'] = $request['name_ar'];
        $paidCategory['name->en'] = $request['name_en'];
        if ($request->hasFile('image')) $paidCategory->setImageAttribute();
        $paidCategory->price = $request['price'];
        $paidCategory->save();
        foreach ($request['workers'] as $worker) {

            WorkerCategory::create([
                'worker_id' => $worker,
                'category_id' => $paidCategory->id
            ]);

        }
        toast('تمت العملية بنجاح', 'success');
        return redirect()->route('paidCategories.index');
    }

    public function edit($id)
    {
        $workers = User::whereType('worker')->whereAdminApprove('true')->get();
        $row = Category::findOrFail($id);
        return view('admin.paidCategories.edit', compact('workers', 'row'));
    }

    public function update($id, Request $request)
    {
        $this->validate($request, [
            'name_ar' => 'required',
            'name_en' => 'required',
            'image' => 'nullable|image',
            'price' => 'required|max:191',
            'workers' => 'required'
        ], [
            'workers.required' => 'رجاء اختيار مقدميين خدمات'
        ]);
        $paidCategory = Category::findOrFail($id);
        $paidCategory['name->ar'] = $request['name_ar'];
        $paidCategory['name->en'] = $request['name_en'];
        if ($request->hasFile('image')) $paidCategory->setImageAttribute();
        $paidCategory->price = $request['price'];
        $paidCategory->update();
        WorkerCategory::whereCategoryId($id)->delete();
        foreach ($request['workers'] as $worker) {

            WorkerCategory::create([
                'worker_id' => $worker,
                'category_id' => $paidCategory->id
            ]);

        }
        toast('تمت العملية بنجاح', 'success');
        return redirect()->route('paidCategories.index');
    }

    public function destroy($id)
    {
        Category::deleted($id);
        toast('تمت العملية بنجاح', 'success');
        return redirect()->route('paidCategories.index');
    }
}
