<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\Notification;
use App\Models\Offer;
use App\Models\Order;
use App\Models\Setting;
use App\Models\UserToken;
use App\User;
use Carbon\Carbon;
use Edujugon\PushNotification\PushNotification;
use Illuminate\Http\Request;

class SecondOrdersController extends Controller
{
    public function index()
    {
        $rows = Order::where('secondPayCheck', 'false')->where('second_transfer_image', '!=', null)->orderByDesc('id')->get();
        return view('admin.second_orders.index', compact('rows'));
    }

    public function edit($id)
    {
        $row = Order::find($id);
        return view('admin.second_orders.edit', compact('row'));
    }

    public function update($id, Request $request)
    {
        $request->validate([
            'title' => 'required|max:191',
            'description' => 'required',
            'address_id' => 'required',
            'date' => 'required|max:191',
            'days_count' => 'required|max:191'

        ]);


        $order = Order::findOrFail($id);
        if ($request['system_money'] == 'true') $order->system_money = 0;
        $order->title = $request['title'];
        $order->description = $request['description'];
        $order->status = $request['status'];
        $order->date = Carbon::parse($request->date);
        $order->address_id = $request['address_id'];
        $order->days_count = $request['days_count'];
        if ($request['status'] == 'paid') $order->secondPayCheck = 'true';

        $order->update();


        toast('تم حفظ التغييرات بنجاح', 'success');
        return redirect()->route('orders.index');


    }

    public function second_order_filter(Request $request)
    {
        $rows = Order::whereWorkerId($request['worker_id'])->where('secondPayCheck', 'false')->where('second_transfer_image', '!=', null)->get();
        if ($request['start'] && $request['end']) {

            if ($request['start'] == $request['end']) {
                $rows = $rows->whereDate('created_at', '>=', Carbon::parse($request['start'])->toDateString());

            } else {
                $rows = $rows->whereBetween('created_at', [Carbon::parse($request['start']), Carbon::parse($request['end'])]);

            }
        } elseif ($request['start'] && $request['end'] == null) {

            $rows = $rows->where('created_at', '>=', Carbon::parse($request['start']));
        } elseif ($request['end'] && $request['start'] == null) {
            $rows = $rows->where('created_at', '<=', Carbon::parse($request['end']));
        }

        return view('admin.orders.index', compact('rows'));

    }

    public function destroy($id)
    {
        Order::destroy($id);
        toast('تم الحذف بنجاح', 'success');
        return redirect()->back();
    }

    public function show($id)
    {
        $row = Order::find($id);
        $categories = $row->categories;
        return view('admin.second_orders.show', compact('row', 'categories'));
    }
}
