<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\Category;
use App\Models\SpecialService;
use Illuminate\Http\Request;

class WorkerServicesController extends Controller
{
    public function index($provider_id)
    {
        $rows = SpecialService::whereProviderId($provider_id)->get();
        return view('admin.special_services.index', compact('rows','provider_id'));
    }

    public function create($provider_id)
    {
        $categories = Category::whereParentId(null)->get();
        return view('admin.special_services.create', compact('categories', 'provider_id'));
    }

    public function store($provider_id ,Request $request)
    {
        $this->validate($request, [

            'category_id' => 'required',
            'price' => 'required',
            'name_ar' => 'required',
            'name_en' => 'required',
            'image' => 'required|image'
        ]);
        $service = new SpecialService();
        $service['name->ar'] = $request['name_ar'];
        $service['name->en'] = $request['name_en'];
        $service->provider_id = $provider_id;
        $service['category_id'] = $request['category_id'];
        $service['price'] = $request['price'];
        if ($request->hasFile('image')) $service->setImageAttribute();
        $service->save();
        toast('تم العمليه بنجاح', 'success');
        return redirect()->route('workers_services', $request['provider_id']);
    }

    public function edit($id)
    {
        $row = SpecialService::findOrFail($id);
        $categories = Category::whereParentId(null)->get();
        return view('admin.special_services.edit', compact('row', 'categories'));
    }

    public function update($id, Request $request)
    {
        $this->validate($request, [
            'category_id' => 'required',
            'price' => 'required',
            'name_ar' => 'required',
            'name_en' => 'required',
            'image' => 'nullable|image'
        ]);
        $service = SpecialService::findOrFail($id);
        $service['name->ar'] = $request['name_ar'];
        $service['name->en'] = $request['name_en'];

        $service['category_id'] = $request['category_id'];
        $service['price'] = $request['price'];
        if ($request->hasFile('image')) $service->setImageAttribute();
        $service->update();
        toast('تم العمليه بنجاح', 'success');
        return redirect()->route('workers_services', $service->provider_id);
    }

    public function destroy($id)
    {
        SpecialService::destroy($id);
        toast('تم العمليه بنجاح', 'success');
        return redirect()->back();

    }

}
