<?php

namespace App\Http\Resources;

use App\Models\Address;
use App\Models\Setting;
use Carbon\Carbon;
use Illuminate\Http\Resources\Json\JsonResource;
use JWTAuth;

class OffersResource extends JsonResource
{


    public function toArray($request)
    {

        $lang = $request->header('Accept-Language', 'ar');
        \App::setLocale($lang);
        $lat1 = 0;
        $lng1 = 0;


        if ($request->header('Authorization')) {
            if (!$user = JWTAuth::parseToken()->authenticate()) {
                return response()->json(['value' => false, 'msg' => \Lang::get('data.wrong_token'), 'code' => 401]);
            }

            $address = $this->order->address_detail;
            $lat1 = $address->lat;
            $lng1 = $address->lng;
        }


        $distance = calculateDistance($lat1, $lng1, $this->worker->lat, $this->worker->lng);


        $setting = Setting::first();
        $offerAndDeliverPrice = (integer)$this->price + (integer)$this->deliver_price;
        $allPriceAndFee = $offerAndDeliverPrice + ($offerAndDeliverPrice * $setting->fee / 100);
        $firstPay = $allPriceAndFee * 15 / 100;


        return [
            'id' => $this->id,
            'worker_id' => $this->worker_id ? (integer)$this->worker_id : 0,
            'worker_username' => $this->worker ? $this->worker->username : '',
            'worker_mobile' => $this->worker ? $this->worker->mobile : '',
            'worker_email' => $this->worker ? $this->worker->email : '',
            'worker_image' => ($this->worker && $this->worker->image) ? asset('images/users/' . $this->worker->image) : '',
            'worker_rate' => $this->worker_id ? getUserRate($this->worker_id) : 0,
            'worker_address' => ($this->worker_id && $this->worker->city) ? $this->worker->city->name[$lang] : '',
            'worker_lat' => ($this->worker_id && $this->worker->lat) ? $this->worker->lat : "",
            'worker_lng' => ($this->worker_id && $this->worker->lng) ? $this->worker->lng : "",
            'worker_job' => $this->worker_id ? $this->worker->job : "",
            "order_id" => $this->order_id,
            'price' => $this->price,
            'comment' => $this->comment,
            'status' => $this->status,
            'deliver_price' => $this->deliver_price ? $this->deliver_price : '',
            'allPriceAndFee' => (integer)$allPriceAndFee,
            'firstPay' => (integer)$firstPay,
            'distance' => (integer)$distance,
            'time' => Carbon::parse($this->created_at)->toDateString()
        ];
    }

}
