<?php

namespace App\Models;

use App\User;
use Illuminate\Database\Eloquent\Model;

class Order extends Model
{

    protected $table = 'orders';
    public $timestamps = true;
    protected $fillable = array('user_id', 'payment_method', 'title', 'transfer_image', 'bank_id', 'description', 'city_id', 'lat', 'lng', 'address', 'date', 'start_time', 'finish_time', 'worker_id', 'price_offer', 'total_price', 'payment_type', 'finish_code', 'status', 'code', 'offer_id', 'system_money', 'address_id', 'days_count', 'first_paid', 'complete_paid', 'deliver_price', 'firstPayCheck', 'secondPayCheck', 'second_transfer_image', 'second_bank_id', 'categoryOffer_id');

    protected $casts = ['category_offer_image'];

    public function getCategoryOfferImageAttribute()
    {
        $image = $this->categoryOffer->image;
        $data = [];
        $arr['id'] = 1;
        $arr['image'] = $image;
        $data[]=$arr;
        return collect($data);
    }

    public function categoryOffer()
    {
        return $this->belongsTo(CategoriesOffer::class,'categoryOffer_id');
    }

//    flag = ['firstPay','secondPay'];
    public function getLevelPaymentAttribute($flag)
    {
        $firstPay = 0;
        $secondPay = 0;
        $secondWorkerPay = 0;
        if ($this->offer_id) {
            $offer = Offer::find($this->offer_id);
            $setting = Setting::first();


            $offerAndDeliverPrice = (integer)$offer->price + (integer)$offer->deliver_price;
            if ($this->coupon) {

                $code = Coupons::whereCode($this->coupon)->first();


                $allPriceAndFee = round($offerAndDeliverPrice + ($offerAndDeliverPrice * $setting->fee / 100), 2);

                if ($code->discount_type == 'discount'){
                    $discount_amount = $allPriceAndFee * $code->discount_amount / 100;

                }
                else{
                    $discount_amount = $code->discount_amount ;
                }

                $max_discount = $code->max_discount;


                if ($discount_amount > $max_discount) {

                    $sub_amount = $max_discount;

                } else {

                    $sub_amount = $discount_amount;

                }


                $allPriceAndFee = $allPriceAndFee - $sub_amount;

            } else {
                $allPriceAndFee = round($offerAndDeliverPrice + ($offerAndDeliverPrice * $setting->fee / 100), 2);

            }

            $firstPay = $allPriceAndFee * 15 / 100;
            $secondPay = $allPriceAndFee - $firstPay;
            $secondWorkerPay = round($offerAndDeliverPrice * 85 / 100, 2);

        }
        if ($flag == 'firstPay') {

            return $firstPay;

        } elseif ($flag == 'secondPay') {

            return $secondPay;

        } elseif ($flag == 'workerSecondPay') {
            return $secondWorkerPay;
        }
    }


    public function offer()
    {
        return $this->hasOne(Offer::class, 'offer_id');
    }

    public function city()
    {
        return $this->belongsTo(City::class, 'city_id');
    }

    public function user()
    {
        return $this->belongsTo(User::class, 'user_id');
    }

    public function worker()
    {
        return $this->belongsTo(User::class, 'worker_id');
    }

    public function images()
    {
        return $this->hasMany(OrderImage::class, 'order_id');
    }

    public function categories()
    {
        return $this->belongsToMany(Category::class, 'order_categories', 'order_id', 'category_id');
    }

    public function offers()
    {
        return $this->hasMany(Offer::class, 'order_id');
    }

    public function address_detail()
    {
        return $this->belongsTo(Address::class, 'address_id');
    }

}
